@@ -1,12 +1,11 @@
-from FreeTAKServer.model.FTSModel.fts_protocol_object import FTSProtocolObject
 from FreeTAKServer.model.FTSModelVariables.ToolVariables import ToolVariables as vars
 
-class Tool(FTSProtocolObject):
+class Tool:
     def __init__(self):
         self.INTAG = None
 
     @staticmethod
-    def ExcheckUpdate(INTAG=vars.ExcheckUpdate().INTAG, ):
+    def CreateExCheckTemplate(INTAG=vars.CreateExCheckTemplate().INTAG, ):
         tool = Tool()
 
         tool.setINTAG(INTAG)
