@@ -1,6 +1,6 @@
-from FreeTAKServer.model.FTSModel.fts_protocol_object import FTSProtocolObject
 from FreeTAKServer.model.FTSModelVariables._GroupVariables import _GroupVariables as vars
-class _Group(FTSProtocolObject):
+
+class _Group:
     def __init__(self):
         self.name = None
         self.role = None
