@@ -1,6 +1,6 @@
 class KeywordsVariables:
     @classmethod
-    def ExcheckUpdate(cls):
+    def CreateExCheckTemplate(cls):
         cls.INTAG = None
         return cls
 
