@@ -29,13 +29,13 @@ class PresencePost(Presence):
         return self.name
     
     def setrole(self, role):
-        self.role = RestEnumerations.roles[role]
+        self.role = RestEnumerations.role[role]
 
     def getrole(self):
         return self.role
     
     def setteam(self, team):
-        self.team = RestEnumerations.teams[team]
+        self.team = RestEnumerations.team[team]
 
     def getteam(self):
         return self.team    
